@@ -270,7 +270,9 @@ window.service_edit_popup = new class {
 			parameters = {row_index};
 		}
 
-		const overlay = PopUp('popup.service.statusrule.edit', parameters, {dialogueid: 'service_status_rule_edit'});
+		const overlay = PopUp('popup.service.statusrule.edit', parameters,
+			{dialogueid: 'service_status_rule_edit', dialogue_class: 'modal-popup-medium'}
+		);
 
 		overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => {
 			if (row !== null) {
@@ -380,7 +382,7 @@ window.service_edit_popup = new class {
 		const overlay = PopUp('popup.services', {
 			title: <?= json_encode(_('Add child services')) ?>,
 			exclude_serviceids
-		}, {dialogueid: 'services'});
+		}, {dialogueid: 'services', dialogue_class: 'modal-popup-generic'});
 
 		overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => {
 			for (const service of e.detail) {
@@ -410,7 +412,7 @@ window.service_edit_popup = new class {
 		const overlay = PopUp('popup.services', {
 			title: <?= json_encode(_('Add parent services')) ?>,
 			exclude_serviceids
-		}, {dialogueid: 'services'});
+		}, {dialogueid: 'services', dialogue_class: 'modal-popup-generic'});
 
 		overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => {
 			const data = [];
@@ -474,7 +476,7 @@ window.service_edit_popup = new class {
 
 		this.overlay.setLoading();
 
-		const curl = new Curl('zabbix.php', false);
+		const curl = new Curl('zabbix.php');
 		curl.setArgument('action', this.serviceid !== null ? 'service.update' : 'service.create');
 
 		this._post(curl.getUrl(), fields, (response) => {
