@@ -509,7 +509,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 				'query_fields' => getRequest('query_fields', []),
 				'posts' => getRequest('posts'),
 				'status_codes' => getRequest('status_codes', DB::getDefault('items', 'status_codes')),
-				'follow_redirects' => (int) getRequest('follow_redirects'),
+				'follow_redirects' => getRequest('follow_redirects', HTTPTEST_STEP_FOLLOW_REDIRECTS_OFF),
 				'post_type' => (int) getRequest('post_type'),
 				'http_proxy' => getRequest('http_proxy'),
 				'headers' => getRequest('headers', []),
