@@ -495,19 +495,19 @@ var hintBox = {
 		jQuery(appendTo).append(box);
 
 		target.observer = new MutationObserver(() => {
-			const node = target instanceof Node ? target : target[0];
+			const element = target instanceof jQuery ? target[0] : target;
 
-			if (document.body.contains(node)) {
-				return;
+			if (!isVisible(element)) {
+				hintBox.deleteHint(target);
 			}
+		});
 
-			hintBox.deleteHint(target);
-		})
-
-		target.observer.observe(document, {
-			childList: true,
-			subtree: true
-		})
+		target.observer.observe(document.body, {
+			attributes: true,
+			attributeFilter: ['style', 'class'],
+			subtree: true,
+			childList: true
+		});
 
 		return box;
 	},
@@ -644,6 +644,16 @@ var hintBox = {
 		}
 	},
 
+	deleteAll: () => {
+		for (let i = overlays_stack.length - 1; i >= 0; i--) {
+			const overlay = overlays_stack.getById(overlays_stack.stack[i]);
+
+			if (overlay.type === 'hintbox') {
+				hintBox.deleteHint(overlay.element);
+			}
+		}
+	},
+
 	getUniqueId: function() {
 		var hintboxid = Math.random().toString(36).substring(7);
 		while (jQuery('[data-hintboxid="' + hintboxid + '"]').length) {
@@ -655,71 +665,47 @@ var hintBox = {
 };
 
 /**
- * Add object to the list of favourites.
- */
-function add2favorites(object, objectid) {
-	sendAjaxData('zabbix.php?action=favourite.create', {
-		data: {
-			object: object,
-			objectid: objectid
-		}
-	});
-}
-
-/**
- * Remove object from the list of favourites. Remove all favourites if objectid==0.
- */
-function rm4favorites(object, objectid) {
-	sendAjaxData('zabbix.php?action=favourite.delete', {
-		data: {
-			object: object,
-			objectid: objectid
-		}
-	});
-}
-
-/**
- * Toggles filter state and updates title and icons accordingly.
+ * Perform JSON-RPC Zabbix API call.
  *
- * @param {string} 	idx					User profile index
- * @param {string} 	value				Value
- * @param {object} 	idx2				An array of IDs
- * @param {integer} profile_type		Profile type
+ * @param {string} method
+ * @param {object} params
+ * @param {int}    id
+ *
+ * @returns {Promise<any>}
  */
-function updateUserProfile(idx, value, idx2, profile_type = PROFILE_TYPE_INT) {
-	const value_fields = {
-		[PROFILE_TYPE_INT]: 'value_int',
-		[PROFILE_TYPE_STR]: 'value_str'
-	};
-
-	return sendAjaxData('zabbix.php?action=profile.update', {
-		data: {
-			idx: idx,
-			[value_fields[profile_type]]: value,
-			idx2: idx2
-		}
-	});
+function ApiCall(method, params, id = 1) {
+	return fetch(new Curl('api_jsonrpc.php').getUrl(), {
+		method: 'POST',
+		headers: {
+			'Content-Type': 'application/json'
+		},
+		credentials: 'same-origin',
+		body: JSON.stringify({
+			jsonrpc: '2.0',
+			method,
+			params,
+			id
+		}),
+	}).then((response) => response.json());
 }
 
-function changeWidgetState(obj, widgetId, idx) {
-	var widgetObj = jQuery('#' + widgetId + '_widget'),
-		css = switchElementClass(obj, 'btn-widget-collapse', 'btn-widget-expand'),
-		state = 0;
+/**
+ * Section collapse toggle.
+ *
+ * @param {string}      id
+ * @param {string|null} profile_idx  If not null, stores state in profile.
+ */
+function toggleSection(id, profile_idx) {
+	const section = document.getElementById(id);
+	const toggle = section.querySelector('.section-toggle');
 
-	if (css === 'btn-widget-expand') {
-		jQuery('.body', widgetObj).slideUp(50);
-		jQuery('.dashboard-widget-foot', widgetObj).slideUp(50);
-	}
-	else {
-		jQuery('.body', widgetObj).slideDown(50);
-		jQuery('.dashboard-widget-foot', widgetObj).slideDown(50);
+	let is_collapsed = section.classList.contains('section-collapsed');
 
-		state = 1;
-	}
+	section.classList.toggle('section-collapsed', !is_collapsed);
+	toggle.setAttribute('title', is_collapsed ? t('S_COLLAPSE') : t('S_EXPAND'));
 
-	obj.title = (state == 1) ? t('S_COLLAPSE') : t('S_EXPAND');
-	if (idx !== '' && typeof idx !== 'undefined') {
-		updateUserProfile(idx, state, []);
+	if (profile_idx !== '') {
+		updateUserProfile(profile_idx, is_collapsed ? '1' : '0', []);
 	}
 }
 
@@ -1019,72 +1005,6 @@ function getConditionFormula(conditions, evalType) {
 }(jQuery));
 
 jQuery(function ($) {
-	var verticalHeaderTables = {};
-
-	$.fn.makeVerticalRotation = function() {
-		this.each(function(i) {
-			var table = $(this);
-
-			if (table.data('rotated') == 1) {
-				return;
-			}
-			table.data('rotated', 1);
-
-			var cellsToRotate = $('.vertical_rotation', table),
-				betterCells = [];
-
-			// insert spans
-			cellsToRotate.each(function() {
-				var cell = $(this),
-					text = $('<span>', {
-						text: cell.html()
-					}).css({'white-space': 'nowrap'});
-
-				cell.text('').append(text);
-			});
-
-			// rotate cells
-			cellsToRotate.each(function() {
-				var cell = $(this),
-					span = cell.children(),
-					height = cell.height(),
-					width = span.width(),
-					transform = (width / 2) + 'px ' + (width / 2) + 'px';
-
-				var css = {};
-
-				css['transform-origin'] = transform;
-				css['-webkit-transform-origin'] = transform;
-				css['-moz-transform-origin'] = transform;
-				css['-o-transform-origin'] = transform;
-
-				var divInner = $('<div>', {
-					'class': 'vertical_rotation_inner'
-				})
-					.css(css)
-					.append(span.text());
-
-				var div = $('<div>', {
-					height: width,
-					width: height
-				})
-					.append(divInner);
-
-				betterCells.push(div);
-			});
-
-			cellsToRotate.each(function(i) {
-				$(this).html(betterCells[i]);
-			});
-
-			table.on('remove', function() {
-				delete verticalHeaderTables[table.attr('id')];
-			});
-
-			verticalHeaderTables[table.attr('id')] = table;
-		});
-	};
-
 	if (ED && typeof sessionStorage.scrollTop !== 'undefined') {
 		$('.wrapper').scrollTop(sessionStorage.scrollTop);
 		sessionStorage.removeItem('scrollTop');
