@@ -474,7 +474,7 @@ function getMenuPopupMapElementTrigger(options) {
 
 		items.push({
 			label: t('Problems'),
-			disabled: !options.showEvents,
+			disabled: !options.show_events,
 			url: url.getUrl()
 		});
 	}
@@ -492,7 +492,7 @@ function getMenuPopupMapElementTrigger(options) {
 				label: item.name,
 				url: url.getUrl()
 			});
-		};
+		}
 
 		items.push({
 			label: t('History'),
@@ -542,7 +542,7 @@ function getMenuPopupMapElementTrigger(options) {
 					disabled: item.params.is_webitem,
 					url: url.getUrl()
 				});
-			};
+			}
 
 			config_urls.push({
 				label: t('Items'),
@@ -671,7 +671,10 @@ function getMenuPopupDashboard(options, trigger_element) {
 				clickCallback: function () {
 					jQuery(this).closest('.menu-popup').menuPopup('close', null);
 
-					PopUp('popup.scheduledreport.list', parameters, {trigger_element});
+					PopUp('popup.scheduledreport.list', parameters, {
+						dialogue_class: 'modal-popup-generic',
+						trigger_element
+					});
 				},
 				disabled: !options.has_related_reports
 			}
@@ -683,7 +686,10 @@ function getMenuPopupDashboard(options, trigger_element) {
 				clickCallback: function () {
 					jQuery(this).closest('.menu-popup').menuPopup('close', null);
 
-					PopUp('popup.scheduledreport.edit', parameters, {trigger_element});
+					PopUp('popup.scheduledreport.edit', parameters, {
+						dialogue_class: 'modal-popup-generic',
+						trigger_element
+					});
 				}
 			});
 		}
@@ -700,20 +706,31 @@ function getMenuPopupDashboard(options, trigger_element) {
 /**
  * Get menu popup trigger section data.
  *
- * @param {string} options['triggerid']                   Trigger ID.
- * @param {string} options['eventid']                     (optional) Required for "Update problem" section and event
+ * @param {object} options
+ *        {string} options['triggerid']                   Trigger ID.
+ *        {bool}   options['allowed_actions_change_problem_ranking']
+ *                                                        Whether user is allowed to change event rank.
+ *        {bool}   options['allowed_ui_conf_hosts']       Whether user has access to Configuration > Hosts.
+ *        {bool}   options['allowed_ui_latest_data']      Whether user has access to Monitoring > Latest data.
+ *        {bool}   options['allowed_ui_problems']         Whether user has access to Monitoring > Problems.
+ *        {bool}   options['backurl']                     URL from where the menu popup was called.
+ *        {bool}   options['show_events']                 Show Problems item enabled. Default: false.
+ *        {string} options['eventid']                     (optional) Required for "Update problem" section and event
  *                                                        rank change.
- * @param {object} options['items']                       Link to trigger item history page (optional).
- * @param {string} options['items'][]['name']             Item name.
- * @param {object} options['items'][]['params']           Item URL parameters ("name" => "value").
- * @param {bool}   options['update_problem']              (optional) Whether to show "Update problem" section.
- * @param {object} options['configuration']               Link to trigger configuration page (optional).
- * @param {bool}   options['showEvents']                  Show Problems item enabled. Default: false.
- * @param {string} options['url']                         Trigger URL link (optional).
+ *        {array}  options['eventids']                    (optional)
+ *        {array}  options['csrf_tokens']                 (optional) CSRF tokens.
+ *        {string} options['csrf_tokens']['acknowledge']  (optional) CSRF token for acknowledge action.
+ *        {string} options['csrf_tokens']['scriptexec']   (optional) CSRF token for script execution.
+ *        {array}  options['items']                       (optional) Link to trigger item history page.
+ *        {string} options['items'][]['name']             Item name.
+ *        {object} options['items'][]['params']           Item URL parameters ("name" => "value").
+ *        {bool}   options['mark_as_cause']               (optional) Whether to enable "Mark as cause".
+ *        {bool}   options['mark_selected_as_symptoms']   (optional) Whether to enable "Mark selected as symptoms".
+ *        {bool}   options['show_update_problem']         (optional) Whether to show "Update problem".
+ *        {bool}   options['show_rank_change_cause']      (optional) Whether to show "Mark as cause".
+ *        {bool}   options['show_rank_change_symptom']    (optional) Whether to show "Mark selected as symptoms".
+ *        {array}  options['urls']                        (optional) Links.
  * @param {object} trigger_element                        UI element which triggered opening of overlay dialogue.
- * @param {array} options[csrf_tokens][]
- * @param {string} options[csrf_tokens][]['scriptexec']   CSRF token for script execution.
- * @param {string} options[csrf_tokens][]['acknowledge']  CSRF token for acknowledge action.
  *
  * @return array
  */
@@ -731,22 +748,11 @@ function getMenuPopupTrigger(options, trigger_element) {
 
 		items.push({
 			label: t('Problems'),
-			disabled: !options.showEvents,
+			disabled: !options.show_events,
 			url: url.getUrl()
 		});
 	}
 
-	if ('update_problem' in options) {
-		items.push({
-			label: t('Update problem'),
-			clickCallback: function() {
-				jQuery(this).closest('.menu-popup-top').menuPopup('close', null);
-
-				acknowledgePopUp({eventids: [options.eventid]}, trigger_element);
-			}
-		});
-	}
-
 	// items problems
 	if (options.allowed_ui_latest_data && options.items.length) {
 		const history = [];
@@ -760,7 +766,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 				label: item.name,
 				url: url.getUrl()
 			});
-		};
+		}
 
 		items.push({
 			label: t('History'),
@@ -775,6 +781,20 @@ function getMenuPopupTrigger(options, trigger_element) {
 		});
 	}
 
+	if ('show_update_problem' in options && options.show_update_problem) {
+		sections.push({
+			label: t('Actions'),
+			items: [{
+				label: t('Update problem'),
+				clickCallback: function() {
+					jQuery(this).closest('.menu-popup-top').menuPopup('close', null);
+
+					acknowledgePopUp({eventids: [options.eventid]}, trigger_element);
+				}
+			}]
+		});
+	}
+
 	// configuration
 	if (options.allowed_ui_conf_hosts) {
 		const config_urls = [];
@@ -784,6 +804,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 		url.setArgument('form', 'update');
 		url.setArgument('triggerid', options.triggerid);
 		url.setArgument('context', 'host');
+		url.setArgument('backurl', options.backurl);
 
 		config_urls.push({
 			label: t('Trigger'),
@@ -796,6 +817,7 @@ function getMenuPopupTrigger(options, trigger_element) {
 				url.setArgument('form', 'update');
 				url.setArgument('itemid', item.params.itemid);
 				url.setArgument('context', 'host');
+				url.setArgument('backurl', options.backurl);
 
 				item_urls.push({
 					label: item.name,
@@ -826,8 +848,8 @@ function getMenuPopupTrigger(options, trigger_element) {
 		curl.setArgument('action', 'popup.acknowledge.create');
 
 		/*
-		 * Some widgets cannot show symptoms. So it is not possible to convert to symptoms cause if only cause evets are
-		 * displayed.
+		 * Some widgets cannot show symptoms. So it is not possible to convert to symptoms cause if only cause events
+		 * are displayed.
 		 */
 		if (typeof options.show_rank_change_cause !== 'undefined' && options.show_rank_change_cause) {
 			// Must be synced with PHP ZBX_PROBLEM_UPDATE_RANK_TO_CAUSE.
@@ -965,6 +987,7 @@ function getMenuPopupTrigger(options, trigger_element) {
  * @param bool   options['trends']                      Are trends available.
  * @param bool   options['allowed_ui_conf_hosts']       Whether user has access to configuration hosts pages.
  * @param bool   options['isWriteable']                 Whether user has read and write access to host and its items.
+ * @param string options['context']                     Determines whether the menu is made for host or template item.
  *
  * @return array
  */
@@ -974,55 +997,57 @@ function getMenuPopupItem(options) {
 	const items = [];
 	let url;
 
-	// latest data link
-	if (options.allowed_ui_latest_data) {
-		url = new Curl('zabbix.php');
-		url.setArgument('action', 'latest.view');
-		url.setArgument('hostids[]', options.hostid);
-		url.setArgument('name', options.name);
-		url.setArgument('filter_set', '1');
+	if (options.context !== 'template') {
+		// latest data link
+		if (options.allowed_ui_latest_data) {
+			url = new Curl('zabbix.php');
+			url.setArgument('action', 'latest.view');
+			url.setArgument('hostids[]', options.hostid);
+			url.setArgument('name', options.name);
+			url.setArgument('filter_set', '1');
+
+			items.push({
+				label: t('Latest data'),
+				url: url.getUrl()
+			});
+		}
+
+		url = new Curl('history.php');
+		url.setArgument('action', 'showgraph');
+		url.setArgument('itemids[]', options.itemid);
 
 		items.push({
-			label: t('Latest data'),
-			url: url.getUrl()
+			label: t('Graph'),
+			url: url.getUrl(),
+			disabled: !options.showGraph
+		});
+
+		url = new Curl('history.php');
+		url.setArgument('action', 'showvalues');
+		url.setArgument('itemids[]', options.itemid);
+
+		items.push({
+			label: t('Values'),
+			url: url.getUrl(),
+			disabled: !options.history && !options.trends
+		});
+
+		url = new Curl('history.php');
+		url.setArgument('action', 'showlatest');
+		url.setArgument('itemids[]', options.itemid);
+
+		items.push({
+			label: t('500 latest values'),
+			url: url.getUrl(),
+			disabled: !options.history && !options.trends
+		});
+
+		sections.push({
+			label: t('View'),
+			items: items
 		});
 	}
 
-	url = new Curl('history.php');
-	url.setArgument('action', 'showgraph');
-	url.setArgument('itemids[]', options.itemid);
-
-	items.push({
-		label: t('Graph'),
-		url: url.getUrl(),
-		disabled: !options.showGraph
-	});
-
-	url = new Curl('history.php');
-	url.setArgument('action', 'showvalues');
-	url.setArgument('itemids[]', options.itemid);
-
-	items.push({
-		label: t('Values'),
-		url: url.getUrl(),
-		disabled: !options.history && !options.trends
-	});
-
-	url = new Curl('history.php');
-	url.setArgument('action', 'showlatest');
-	url.setArgument('itemids[]', options.itemid);
-
-	items.push({
-		label: t('500 latest values'),
-		url: url.getUrl(),
-		disabled: !options.history && !options.trends
-	});
-
-	sections.push({
-		label: t('View'),
-		items: items
-	});
-
 	if (options.allowed_ui_conf_hosts) {
 		const config_urls = [];
 		const config_triggers = {
@@ -1112,26 +1137,28 @@ function getMenuPopupItem(options) {
 		});
 	}
 
-	const execute = {
-		label: t('Execute now'),
-		disabled: !options.isExecutable
-	};
-
-	if (options.isExecutable) {
-		execute.clickCallback = function () {
-			jQuery(this).closest('.menu-popup').menuPopup('close', null);
-
-			view.checkNow(options.itemid);
+	if (options.context !== 'template') {
+		const execute = {
+			label: t('Execute now'),
+			disabled: !options.isExecutable
 		};
+
+		if (options.isExecutable) {
+			execute.clickCallback = function() {
+				jQuery(this).closest('.menu-popup').menuPopup('close', null);
+
+				view.checkNow(options.itemid);
+			};
+		}
+
+		actions.push(execute);
+
+		sections.push({
+			label: t('Actions'),
+			items: actions
+		});
 	}
 
-	actions.push(execute);
-
-	sections.push({
-		label: t('Actions'),
-		items: actions
-	});
-
 	return sections;
 }
 
@@ -1264,14 +1291,14 @@ function getMenuPopupDropdown(options, trigger_elem) {
 		else if (options.submit_form) {
 			row.url = 'javascript:void(0);';
 			row.clickCallback = () => {
-				var $_form = trigger_elem.closest('form');
+				const form = trigger_elem.closest('form').get(0);
 
-				if (!$_form.data("action")) {
-					$_form.data("action", $_form.attr("action"));
+				if (!form.dataset.action) {
+					form.dataset.action = form.getAttribute('action');
 				}
 
-				$_form.attr("action", item.url);
-				$_form.submit();
+				form.setAttribute('action', item.url);
+				form.submit();
 			}
 		}
 
@@ -1689,7 +1716,7 @@ jQuery(function($) {
 			// Need to be postponed.
 			setTimeout(function() {
 				$(document)
-					.on('click dragstart contextmenu', {menu: $menu_popup, opener: $opener},
+					.on('click dragstart', {menu: $menu_popup, opener: $opener},
 						menuPopupDocumentCloseHandler
 					)
 					.on('keydown', {menu: $menu_popup}, menuPopupKeyDownHandler);
@@ -1710,7 +1737,7 @@ jQuery(function($) {
 				$('[aria-expanded="true"]', menu_popup).attr({'aria-expanded': 'false'});
 
 				$(document)
-					.off('click dragstart contextmenu', menuPopupDocumentCloseHandler)
+					.off('click dragstart', menuPopupDocumentCloseHandler)
 					.off('keydown', menuPopupKeyDownHandler);
 
 				var overlay = removeFromOverlaysStack('menu-popup', return_focus);
